@@ -1,14 +1,14 @@
 #!/usr/bin/python
 
 #
-# Copyright 2016 David Steele <steele@debian.org>
+# Copyright 2016-2017 David Steele <steele@debian.org>
 # This file is part of comitup
 # Available under the terms of the GNU General Public License version 2
 # or later
 #
 
 import dbus
-import gobject
+from gi.repository.GLib import MainLoop
 
 from dbus.mainloop.glib import DBusGMainLoop
 
@@ -17,7 +17,8 @@ import logging
 if __name__ == '__main__':
     DBusGMainLoop(set_as_default=True)
 
-import nm   # noqa
+import nm       # noqa
+import modemgr  # noqa
 
 
 #
@@ -30,11 +31,13 @@ bus = dbus.SystemBus()
 
 device_path = None
 device_listener = None
+comstate = 'HOTSPOT'
 
 
 def null_fn():
     pass
 
+
 nm_dev_connect = null_fn
 nm_dev_fail = null_fn
 
@@ -43,9 +46,16 @@ nm_dev_fail = null_fn
 #
 
 
-def set_device_callbacks(up, down):
+def set_device_callbacks(state, up, down):
     global nm_dev_connect
     global nm_dev_fail
+    global comstate
+
+    nm_dev_connect = null_fn
+    nm_dev_fail = null_fn
+
+    comstate = state
+    check_device_listener()
 
     nm_dev_connect = up
     nm_dev_fail = down
@@ -81,7 +91,7 @@ def set_device_listener(path):
 def check_device_listener(force=False):
     global device_path
 
-    current_path = nm.get_device_path()
+    current_path = nm.get_device_path(modemgr.get_state_device(comstate))
 
     if force or (current_path and current_path != device_path):
         device_path = current_path
@@ -140,9 +150,9 @@ def main():
     def down():
         print("wifi down")
 
-    set_device_callbacks(up, down)
+    set_device_callbacks('HOTSPOT', up, down)
 
-    loop = gobject.MainLoop()
+    loop = MainLoop()
     loop.run()
 
 
